# CHANGELOG


## v0.64.1 (2026-01-01)

### Bug Fixes

- **update**: Read remote changelog correctly
  ([#219](https://github.com/lt-mayonesa/hexagon/pull/219),
  [`149bee3`](https://github.com/lt-mayonesa/hexagon/commit/149bee30af0ec091322b8c5c3d612bedb5b05ebf))

### Chores

- **ai**: Init claude
  ([`fc1072e`](https://github.com/lt-mayonesa/hexagon/commit/fc1072eb36008af05c4d16aca3d1d6f5cff016ee))

- **cli**: Dependabot housekeeping tool
  ([`2a37ba2`](https://github.com/lt-mayonesa/hexagon/commit/2a37ba2a514454b02576b1510efcb962e02d4477))

- **deps**: Bump actions/download-artifact from 6 to 7
  ([#217](https://github.com/lt-mayonesa/hexagon/pull/217),
  [`f0271df`](https://github.com/lt-mayonesa/hexagon/commit/f0271dfaacdebbdc1a8b64d9a1dd4e50e1548989))

- **deps**: Bump peter-evans/create-pull-request from 7 to 8
  ([#216](https://github.com/lt-mayonesa/hexagon/pull/216),
  [`36da5db`](https://github.com/lt-mayonesa/hexagon/commit/36da5db1178f604af0159d8d1e92e9856e6db0a3))

- **deps**: Bump the npm_and_yarn group across 1 directory with 4 updates
  ([#218](https://github.com/lt-mayonesa/hexagon/pull/218),
  [`4665d42`](https://github.com/lt-mayonesa/hexagon/commit/4665d424326d6b41e3567f9d919f02025f3a9df6))

- **deps-dev**: Bump pytest from 8.4.1 to 9.0.2
  ([#213](https://github.com/lt-mayonesa/hexagon/pull/213),
  [`97abbad`](https://github.com/lt-mayonesa/hexagon/commit/97abbadaaf9bbcaa22be794d2e7824aa10cae3d0))

### Testing

- **e2e**: Fix print_version
  ([`1126557`](https://github.com/lt-mayonesa/hexagon/commit/1126557e4345bedb19265f732426ae775a845557))


## v0.64.0 (2026-01-01)

### Chores

- **deps**: Bump actions/checkout from 3 to 4
  ([#155](https://github.com/lt-mayonesa/hexagon/pull/155),
  [`f10270b`](https://github.com/lt-mayonesa/hexagon/commit/f10270b0abe84fd69c04ed658fa4793799d1aa39))

- **deps**: Bump actions/checkout from 4 to 5
  ([#188](https://github.com/lt-mayonesa/hexagon/pull/188),
  [`51e4114`](https://github.com/lt-mayonesa/hexagon/commit/51e411490c666f2de8d7d2fd010ed5c6a1f43e72))

- **deps**: Bump actions/checkout from 5 to 6
  ([#210](https://github.com/lt-mayonesa/hexagon/pull/210),
  [`894154e`](https://github.com/lt-mayonesa/hexagon/commit/894154e7b5bfb34991bfb0fff0260fdb04a3d720))

- **deps**: Bump actions/download-artifact from 4 to 6
  ([#199](https://github.com/lt-mayonesa/hexagon/pull/199),
  [`6816ccd`](https://github.com/lt-mayonesa/hexagon/commit/6816ccda3208b35aef7a057937f65dd677391cc6))

- **deps**: Bump actions/setup-node from 3 to 4
  ([#157](https://github.com/lt-mayonesa/hexagon/pull/157),
  [`06a3fa2`](https://github.com/lt-mayonesa/hexagon/commit/06a3fa2c3e6bdc407211008ab9f469bf0ec7037d))

- **deps**: Bump actions/setup-node from 4 to 6
  ([#204](https://github.com/lt-mayonesa/hexagon/pull/204),
  [`2f87793`](https://github.com/lt-mayonesa/hexagon/commit/2f877930577de924bfb78712d916b1d5b9f1d117))

- **deps**: Bump actions/setup-python from 5 to 6
  ([#191](https://github.com/lt-mayonesa/hexagon/pull/191),
  [`0ae0427`](https://github.com/lt-mayonesa/hexagon/commit/0ae04270c5878405fb8d172ebcc1cd549d80ca22))

- **deps**: Bump actions/upload-artifact from 4 to 5
  ([#205](https://github.com/lt-mayonesa/hexagon/pull/205),
  [`f407e98`](https://github.com/lt-mayonesa/hexagon/commit/f407e98579a9fb6cb03fa29aee7a80646b63e511))

- **deps**: Bump brace-expansion ([#173](https://github.com/lt-mayonesa/hexagon/pull/173),
  [`69639eb`](https://github.com/lt-mayonesa/hexagon/commit/69639ebbaacdecb1ab198adca3a659514c45cbc7))

- **deps**: Bump markdown from 3.8 to 3.9 ([#189](https://github.com/lt-mayonesa/hexagon/pull/189),
  [`4775c0b`](https://github.com/lt-mayonesa/hexagon/commit/4775c0b1394aeb630b521ad137647946f917ed46))

- **deps**: Bump on-headers ([#209](https://github.com/lt-mayonesa/hexagon/pull/209),
  [`194e503`](https://github.com/lt-mayonesa/hexagon/commit/194e5035ee289a5a1e3ed0f2ab4102d0cb4ae575))

- **deps**: Bump peaceiris/actions-gh-pages from 3 to 4
  ([#156](https://github.com/lt-mayonesa/hexagon/pull/156),
  [`5c59ced`](https://github.com/lt-mayonesa/hexagon/commit/5c59ced0b77c0199512eb934fad02baaca137893))

- **deps**: Bump peter-evans/create-pull-request from 6 to 7
  ([#168](https://github.com/lt-mayonesa/hexagon/pull/168),
  [`18ba47a`](https://github.com/lt-mayonesa/hexagon/commit/18ba47adea9f1097b87450d6ca6537c83506bbb9))

- **deps**: Bump pydantic from 2.11.4 to 2.11.5
  ([#158](https://github.com/lt-mayonesa/hexagon/pull/158),
  [`3adcf72`](https://github.com/lt-mayonesa/hexagon/commit/3adcf72f64fe6cabe44e7e662c0ad1d3cf7c0dd9))

- **deps**: Bump pydantic from 2.11.5 to 2.11.7
  ([#172](https://github.com/lt-mayonesa/hexagon/pull/172),
  [`23b0526`](https://github.com/lt-mayonesa/hexagon/commit/23b052621e1ebecf533e2bff7d8fb5e00e152b56))

- **deps**: Bump python-semantic-release/publish-action
  ([#208](https://github.com/lt-mayonesa/hexagon/pull/208),
  [`241bd62`](https://github.com/lt-mayonesa/hexagon/commit/241bd62ab6595190a9ea753369da477b86a6191c))

- **deps**: Bump python-semantic-release/publish-action
  ([#196](https://github.com/lt-mayonesa/hexagon/pull/196),
  [`6109b90`](https://github.com/lt-mayonesa/hexagon/commit/6109b9084e9ebf4e6387e44b0a09709addc29f5c))

- **deps**: Bump python-semantic-release/publish-action
  ([#171](https://github.com/lt-mayonesa/hexagon/pull/171),
  [`0a13595`](https://github.com/lt-mayonesa/hexagon/commit/0a1359519da6ae0bb4c23a5a67c10ed46158740f))

- **deps**: Bump python-semantic-release/publish-action
  ([#163](https://github.com/lt-mayonesa/hexagon/pull/163),
  [`f9eba75`](https://github.com/lt-mayonesa/hexagon/commit/f9eba75020950e56504a4cd00c9769c94f1a53c5))

- **deps**: Bump python-semantic-release/python-semantic-release
  ([#207](https://github.com/lt-mayonesa/hexagon/pull/207),
  [`13369ea`](https://github.com/lt-mayonesa/hexagon/commit/13369eafce44c8f1a985fa830f76318a99386eb1))

- **deps**: Bump python-semantic-release/python-semantic-release
  ([#197](https://github.com/lt-mayonesa/hexagon/pull/197),
  [`86cc9ac`](https://github.com/lt-mayonesa/hexagon/commit/86cc9ac46abc1d8c7a845b61ff7b7c842ce438f3))

- **deps**: Bump python-semantic-release/python-semantic-release
  ([#170](https://github.com/lt-mayonesa/hexagon/pull/170),
  [`91a6f70`](https://github.com/lt-mayonesa/hexagon/commit/91a6f7095b50c5c1139e8e74f0ea55ba00c846f9))

- **deps**: Bump python-semantic-release/python-semantic-release
  ([#162](https://github.com/lt-mayonesa/hexagon/pull/162),
  [`3af4378`](https://github.com/lt-mayonesa/hexagon/commit/3af43782c19adefcd4b444e417e2bfc30ed70919))

- **deps**: Bump typing-extensions from 4.13.2 to 4.14.0
  ([#169](https://github.com/lt-mayonesa/hexagon/pull/169),
  [`30871f2`](https://github.com/lt-mayonesa/hexagon/commit/30871f2569b696c1d6c1b03fb54731f97ecef8c4))

- **deps-dev**: Bump black from 25.1.0 to 25.9.0
  ([#202](https://github.com/lt-mayonesa/hexagon/pull/202),
  [`196a787`](https://github.com/lt-mayonesa/hexagon/commit/196a7871e33aa37eb049134d1449b5bd4a5f535b))

- **deps-dev**: Bump flake8 from 7.2.0 to 7.3.0
  ([#177](https://github.com/lt-mayonesa/hexagon/pull/177),
  [`d1e4dac`](https://github.com/lt-mayonesa/hexagon/commit/d1e4dac8edb81a78d1a47ff416592fe6d1fff114))

- **deps-dev**: Bump pytest from 8.3.5 to 8.4.0
  ([#166](https://github.com/lt-mayonesa/hexagon/pull/166),
  [`f5b5ccb`](https://github.com/lt-mayonesa/hexagon/commit/f5b5ccb7faa6e86400aa349d172c89304f631c89))

- **deps-dev**: Bump pytest-xdist from 3.6.1 to 3.7.0
  ([#164](https://github.com/lt-mayonesa/hexagon/pull/164),
  [`ab78277`](https://github.com/lt-mayonesa/hexagon/commit/ab78277376fb3664cecde7b1a2eab276809caf94))

- **deps-dev**: Bump pytest-xdist from 3.7.0 to 3.8.0
  ([#182](https://github.com/lt-mayonesa/hexagon/pull/182),
  [`40ca96e`](https://github.com/lt-mayonesa/hexagon/commit/40ca96e428706375f2d200a9129ff89753c1daa0))

- **e2e**: Simplify execute group spec
  ([`b69a047`](https://github.com/lt-mayonesa/hexagon/commit/b69a0473216e088f820dbb9fad014155c62110c6))

### Continuous Integration

- **e2e**: Fix failing e2e builds
  ([`28d6b23`](https://github.com/lt-mayonesa/hexagon/commit/28d6b23844b034c9d0a739af5cd937d690ac5b9a))

- **release**: Remove e2e version bump
  ([`91ed480`](https://github.com/lt-mayonesa/hexagon/commit/91ed4806bc007725cbe5e9a12aaa903a68ad4ecd))

- **release**: Semantic release migration
  ([`61a6b78`](https://github.com/lt-mayonesa/hexagon/commit/61a6b78b044d0d26d5ef6afaf8fad00a3a81b18c))

- **visualizer**: Generate structure diagram
  ([`ef432d7`](https://github.com/lt-mayonesa/hexagon/commit/ef432d745f98583319bfc3dd15466ba6041d5e72))

### Documentation

- Fix broken link
  ([`36965c5`](https://github.com/lt-mayonesa/hexagon/commit/36965c5eb891e87b5f69fb038cfd2c8f70b340cd))

- Update logo and guides
  ([`7c36f28`](https://github.com/lt-mayonesa/hexagon/commit/7c36f288379cc643de6a97a2231dbf668162b7c6))

- **api**: Update inconsistent output api
  ([`620beed`](https://github.com/lt-mayonesa/hexagon/commit/620beed1b81073130f22aa634fe70745a3f4450f))

- **gh-pages**: Create new docs
  ([`7eedf51`](https://github.com/lt-mayonesa/hexagon/commit/7eedf511ded8790292b503323dfbe21db4192497))

- **gh-pages**: Remove unused files
  ([`a0d87e5`](https://github.com/lt-mayonesa/hexagon/commit/a0d87e55667dbe3a4c9be69fb1c1db2531fbb80a))

- **gh-pages**: Remove unused files
  ([`cf6e2c6`](https://github.com/lt-mayonesa/hexagon/commit/cf6e2c6baf6414c8c4490057251f0eb9f478cd13))

- **install**: Use pipx for installing hexagon
  ([`c1b7a4b`](https://github.com/lt-mayonesa/hexagon/commit/c1b7a4b5c6a1d6203f9ebcfb4e7c271e3f7f7b86))

- **prompt**: How to
  ([`b5bafab`](https://github.com/lt-mayonesa/hexagon/commit/b5bafab8e73f8965fc0f56bd1cfa337ed2153065))

- **search**: Add search support
  ([`f123537`](https://github.com/lt-mayonesa/hexagon/commit/f1235376e3501b4ac576f23a3a70086f6a2573c7))

### Features

- Add manual update tools for hexagon and custom CLIs
  ([#211](https://github.com/lt-mayonesa/hexagon/pull/211),
  [`c7a4a00`](https://github.com/lt-mayonesa/hexagon/commit/c7a4a005035c093ad1ac94ff770553adf11d7134))

### Refactoring

- **prompt**: Extract inquiry type detection
  ([`599c020`](https://github.com/lt-mayonesa/hexagon/commit/599c020005ecd169679853812e109539b7e3b2f0))

### Testing

- **e2e**: Execute parallel & sequential specs
  ([#159](https://github.com/lt-mayonesa/hexagon/pull/159),
  [`c078609`](https://github.com/lt-mayonesa/hexagon/commit/c0786095162a0f20ac7a26943156fa47401e48a4))

- **e2e**: Fix flaky hints test
  ([`4257d90`](https://github.com/lt-mayonesa/hexagon/commit/4257d9055d41c48d817dedf3af6171445475210d))

- **unit**: Test naming convention
  ([`1d3e297`](https://github.com/lt-mayonesa/hexagon/commit/1d3e2971b78ac2a9f9b80b9fe670cd1656cc1232))


## v0.63.1 (2025-05-12)

### Bug Fixes

- **release**: Use correct publish tool
  ([`1925fa5`](https://github.com/lt-mayonesa/hexagon/commit/1925fa5e0f3810e7c3b582f405487fcd18828caa))

### Chores

- **e2e**: Reordered group tools to fix flaky test
  ([#154](https://github.com/lt-mayonesa/hexagon/pull/154),
  [`9e5e343`](https://github.com/lt-mayonesa/hexagon/commit/9e5e343390fe2dcfdc117bd2c32611fb46f363c6))


## v0.63.0 (2025-05-11)

### Chores

- **e2e**: Minor code improvements ([#151](https://github.com/lt-mayonesa/hexagon/pull/151),
  [`ebf4f87`](https://github.com/lt-mayonesa/hexagon/commit/ebf4f87213cddc665deef16e5dc1a6e988432659))

- **tests**: Run e2e tests in parallel ([#90](https://github.com/lt-mayonesa/hexagon/pull/90),
  [`5392dbe`](https://github.com/lt-mayonesa/hexagon/commit/5392dbed2ebd0130814def162c61abcbe2699635))

### Features

- **cwd-tools**: Load tools defined in hexagon_tools yaml
  ([#152](https://github.com/lt-mayonesa/hexagon/pull/152),
  [`93fd728`](https://github.com/lt-mayonesa/hexagon/commit/93fd72878761bf01d4761ca7dc476400e39dfe1f))

### Refactoring

- **prompt**: Use Separator tool ([#153](https://github.com/lt-mayonesa/hexagon/pull/153),
  [`faf0cd0`](https://github.com/lt-mayonesa/hexagon/commit/faf0cd05baac2eaba392c46aadb8b5fda2c03ef9))


## v0.62.2 (2025-05-09)

### Bug Fixes

- **errors**: Show traceback on group tools
  ([#150](https://github.com/lt-mayonesa/hexagon/pull/150),
  [`47cae1a`](https://github.com/lt-mayonesa/hexagon/commit/47cae1ab73818d36333bd8f2ce9141da78fae6b4))

### Chores

- **deps**: Bump markdown from 3.7 to 3.8 ([#149](https://github.com/lt-mayonesa/hexagon/pull/149),
  [`2f07726`](https://github.com/lt-mayonesa/hexagon/commit/2f07726e8008c3e4b555e4c94ac7649e03f32bd6))

- **deps-dev**: Bump black from 24.10.0 to 25.1.0
  ([#148](https://github.com/lt-mayonesa/hexagon/pull/148),
  [`f164e25`](https://github.com/lt-mayonesa/hexagon/commit/f164e259832b9b5fdabba0c467692131886715ff))

- **format**: Apply new black version
  ([`92bc198`](https://github.com/lt-mayonesa/hexagon/commit/92bc1985a14a38dca8c87661f0d3322fbecc1d95))

### Continuous Integration

- **release**: Rollback to user token
  ([`55dd61e`](https://github.com/lt-mayonesa/hexagon/commit/55dd61ef043562f3f860fc2db224a85ef79301ce))

- **release**: Setup correct permission on jobs
  ([`587f7a9`](https://github.com/lt-mayonesa/hexagon/commit/587f7a95cc3ac0cf90c126a21f9739abc0b90a07))

- **release**: Use github token on release
  ([`bd6220d`](https://github.com/lt-mayonesa/hexagon/commit/bd6220d20fa9fdb9f4aff1e0ddd1e78dc35e2475))


## v0.62.1 (2025-05-06)

### Bug Fixes

- **args**: Support argparse python 3.12 ([#146](https://github.com/lt-mayonesa/hexagon/pull/146),
  [`03b9772`](https://github.com/lt-mayonesa/hexagon/commit/03b9772ff84e5d3adbf75cbdce1d12a0b4b2dbf1))

- **parse**: Changelog on update ([#145](https://github.com/lt-mayonesa/hexagon/pull/145),
  [`d582ae4`](https://github.com/lt-mayonesa/hexagon/commit/d582ae41d69b0d3d3f5506a365935346dbd4d3ef))

### Chores

- **ci**: Use github token on release
  ([`4762efb`](https://github.com/lt-mayonesa/hexagon/commit/4762efb366cc144918f662ff9512da0cc5a3d87c))

- **deps**: Bump dorny/test-reporter from 1 to 2
  ([#143](https://github.com/lt-mayonesa/hexagon/pull/143),
  [`9571364`](https://github.com/lt-mayonesa/hexagon/commit/9571364216ab1c12fa02e6acc8905bf63c0ef1d2))

- **deps**: Bump packaging from 24.1 to 24.2
  ([#122](https://github.com/lt-mayonesa/hexagon/pull/122),
  [`1913e4c`](https://github.com/lt-mayonesa/hexagon/commit/1913e4cb72726dd0a7841f6ba6cb0fbac72a1c89))

- **deps**: Bump pydantic from 2.8.2 to 2.9.2
  ([#104](https://github.com/lt-mayonesa/hexagon/pull/104),
  [`12b6411`](https://github.com/lt-mayonesa/hexagon/commit/12b64114c3ca92fbee0155c2918db1c33ab5e3da))

- **deps**: Bump pydantic-settings from 2.4.0 to 2.5.2
  ([#102](https://github.com/lt-mayonesa/hexagon/pull/102),
  [`15cf47c`](https://github.com/lt-mayonesa/hexagon/commit/15cf47cf8344b254c7d9b719d571d7fd458a0aab))

- **deps**: Bump pydantic-settings from 2.5.2 to 2.8.1
  ([#141](https://github.com/lt-mayonesa/hexagon/pull/141),
  [`2731eb7`](https://github.com/lt-mayonesa/hexagon/commit/2731eb73bf206d630dfc63403d60bda24659b867))

- **deps**: Bump python-semantic-release/python-semantic-release
  ([#139](https://github.com/lt-mayonesa/hexagon/pull/139),
  [`3d5f880`](https://github.com/lt-mayonesa/hexagon/commit/3d5f8804e2a1ed9ae51892942fefff12aa24fe13))

- **deps**: Bump rich from 13.7.1 to 13.8.1
  ([#100](https://github.com/lt-mayonesa/hexagon/pull/100),
  [`62a13ad`](https://github.com/lt-mayonesa/hexagon/commit/62a13ad0aa1db85e9c59ac9891b38c1b87e4006b))

- **deps**: Bump rich from 13.8.1 to 14.0.0
  ([#144](https://github.com/lt-mayonesa/hexagon/pull/144),
  [`2973b6c`](https://github.com/lt-mayonesa/hexagon/commit/2973b6cb5eb5c2f6b06dff202d7c542563b9a16a))

- **deps**: Bump TrueBrain/actions-flake8 from 2.1 to 2.3
  ([#94](https://github.com/lt-mayonesa/hexagon/pull/94),
  [`3321c46`](https://github.com/lt-mayonesa/hexagon/commit/3321c463df9a528739f3a2134a97ec9998cdf19e))

- **deps**: Bump TrueBrain/actions-flake8 from 2.3 to 2.4
  ([#113](https://github.com/lt-mayonesa/hexagon/pull/113),
  [`6520f2e`](https://github.com/lt-mayonesa/hexagon/commit/6520f2e3bdfa5e9b66075069c1cebfa75d293746))

- **deps-dev**: Bump black from 24.8.0 to 24.10.0
  ([#109](https://github.com/lt-mayonesa/hexagon/pull/109),
  [`9000f9a`](https://github.com/lt-mayonesa/hexagon/commit/9000f9a480ebaa786751d4b186ee83878eb61b96))

- **deps-dev**: Bump flake8-bugbear from 24.4.26 to 24.12.12
  ([#127](https://github.com/lt-mayonesa/hexagon/pull/127),
  [`d6a9322`](https://github.com/lt-mayonesa/hexagon/commit/d6a93221f29d7ff9d2debc6426c6fb44ac1e0e33))

- **deps-dev**: Bump pytest from 8.3.3 to 8.3.5
  ([#142](https://github.com/lt-mayonesa/hexagon/pull/142),
  [`a51c206`](https://github.com/lt-mayonesa/hexagon/commit/a51c20642d2222f1094da7198cc44a9cd103a764))

### Continuous Integration

- **deps**: Migrate to artifact@v4 ([#105](https://github.com/lt-mayonesa/hexagon/pull/105),
  [`09176a7`](https://github.com/lt-mayonesa/hexagon/commit/09176a70663f8ace75d9f027dc8d2b8c1ef9864b))

- **release**: Remove listing dirs
  ([`6cbf706`](https://github.com/lt-mayonesa/hexagon/commit/6cbf706b7620b9b986d249904b30c95e851caec1))


## v0.62.0 (2024-09-21)

### Chores

- **deps**: Bump python-semantic-release/python-semantic-release
  ([#96](https://github.com/lt-mayonesa/hexagon/pull/96),
  [`c02e9d2`](https://github.com/lt-mayonesa/hexagon/commit/c02e9d2fd8ffe20823b0a7a09cc68e976283dfb0))

- **deps-dev**: Bump pytest from 8.3.2 to 8.3.3
  ([#103](https://github.com/lt-mayonesa/hexagon/pull/103),
  [`3723433`](https://github.com/lt-mayonesa/hexagon/commit/37234338eac1ddd6f76472c634337a73d372fda6))

### Continuous Integration

- **dependabot**: Set to run daily
  ([`4eb3206`](https://github.com/lt-mayonesa/hexagon/commit/4eb3206bb85458b7679f654ee0bd0a37845c51e0))

- **release**: Install setuptools before release
  ([`0255451`](https://github.com/lt-mayonesa/hexagon/commit/02554518c25d0fe38df195ed42cdec3bca00b927))

- **release**: Install setuptools before release
  ([`791127c`](https://github.com/lt-mayonesa/hexagon/commit/791127cda44c12baee0da81f073270c85396c4bd))

- **release**: Install wheel before release
  ([`bf528ad`](https://github.com/lt-mayonesa/hexagon/commit/bf528ad17b8510ac9d93fdd5a99f0648af5cac16))

### Features

- **updates**: Use pip to upgrade hexagon ([#92](https://github.com/lt-mayonesa/hexagon/pull/92),
  [`f7e6544`](https://github.com/lt-mayonesa/hexagon/commit/f7e65447e1cc0ba917212be92badfcf69132c778))


## v0.61.0 (2024-08-20)

### Chores

- **ci**: Publish to PyPi
  ([`38b1a2d`](https://github.com/lt-mayonesa/hexagon/commit/38b1a2d75d7423a46a00ac02c50ff265931f3225))

- **deps**: Bump actions/checkout from 3 to 4
  ([#85](https://github.com/lt-mayonesa/hexagon/pull/85),
  [`fa14690`](https://github.com/lt-mayonesa/hexagon/commit/fa146902d735bddce404636871dcd33ee78abf2b))

- **deps**: Bump actions/setup-python from 4 to 5
  ([#86](https://github.com/lt-mayonesa/hexagon/pull/86),
  [`1853b6d`](https://github.com/lt-mayonesa/hexagon/commit/1853b6dd4d27f4e84409d13919736b10fb5dac2c))

- **deps**: Bump markdown from 3.6 to 3.7 ([#89](https://github.com/lt-mayonesa/hexagon/pull/89),
  [`d8b0f83`](https://github.com/lt-mayonesa/hexagon/commit/d8b0f830e06de6392027207c276c0d5aaf08ea22))

- **deps**: Bump nick-fields/retry from 2 to 3
  ([#84](https://github.com/lt-mayonesa/hexagon/pull/84),
  [`dd245aa`](https://github.com/lt-mayonesa/hexagon/commit/dd245aac8a0a5285cf8ef99a5035a4ccfa85ac5b))

- **release**: Configure semantic release v9
  ([`6c95617`](https://github.com/lt-mayonesa/hexagon/commit/6c95617a795b811e5cd066ba5377c49ed1f0c40a))

- **release**: Specify build command
  ([`0dbbf67`](https://github.com/lt-mayonesa/hexagon/commit/0dbbf6776b1cde6cec7e5f31456f6ff22b78f225))

### Features

- Print hexagon package version ([#91](https://github.com/lt-mayonesa/hexagon/pull/91),
  [`b52bfe2`](https://github.com/lt-mayonesa/hexagon/commit/b52bfe2fffc15dcb24ff6ec0064ab43f925ed45c))


## v0.60.0 (2024-08-09)

### Chores

- **deps**: Migrate to pydantic v2 ([#81](https://github.com/lt-mayonesa/hexagon/pull/81),
  [`56ec06e`](https://github.com/lt-mayonesa/hexagon/commit/56ec06e0a1ffcd94530504ddb98cec8598f93911))

- **deps**: Setup dependabot version upgrades
  ([`6c43a24`](https://github.com/lt-mayonesa/hexagon/commit/6c43a2491c79f67f3df09809b54406eb6ca2905b))

### Features

- **prompt**: Allow to provide text suggestions
  ([#88](https://github.com/lt-mayonesa/hexagon/pull/88),
  [`fb1319a`](https://github.com/lt-mayonesa/hexagon/commit/fb1319a7ab7e42acbf76776a8842923d86b17b3e))


## v0.59.0 (2024-04-09)

### Features

- **cli**: Allow configuring entrypoint on install
  ([`ed75377`](https://github.com/lt-mayonesa/hexagon/commit/ed7537743c6fdfe957a095d7ab51b7302df347ec))


## v0.58.1 (2024-04-08)

### Bug Fixes

- **install**: Make bin_path optional arg
  ([`741044a`](https://github.com/lt-mayonesa/hexagon/commit/741044a2244770c18b66dfd972bc1220cab910ad))

### Chores

- **ci**: Fix package step
  ([`5d51e29`](https://github.com/lt-mayonesa/hexagon/commit/5d51e29e017e6fbd493164162f48a8903165729f))


## v0.58.0 (2024-03-30)

### Chores

- **args**: Document .prompt public api
  ([`3c77688`](https://github.com/lt-mayonesa/hexagon/commit/3c7768875faea631d3069a812d2ab973dfbb4550))

- **args**: Fix flake8 errors
  ([`d2197e9`](https://github.com/lt-mayonesa/hexagon/commit/d2197e98204eccd6e6e91d86f9759ba6417d6f1a))

- **ci**: Publish release to pypi
  ([`45eb5fd`](https://github.com/lt-mayonesa/hexagon/commit/45eb5fd75193908478b184e07ced4012690e61f1))

- **deps-dev**: Bump black from 24.2.0 to 24.3.0
  ([#78](https://github.com/lt-mayonesa/hexagon/pull/78),
  [`32da740`](https://github.com/lt-mayonesa/hexagon/commit/32da74066a95a1bbf44787153f518cf81dcd2a3a))

- **dist**: Min python is 3.9 ([#79](https://github.com/lt-mayonesa/hexagon/pull/79),
  [`017ce49`](https://github.com/lt-mayonesa/hexagon/commit/017ce49c80947a4e2ee9162778ec99ad04253b03))

### Documentation

- **readme**: Install from pypi
  ([`6968d45`](https://github.com/lt-mayonesa/hexagon/commit/6968d45b54222086f940f9b635771214c0352bd5))

### Features

- **logger**: Add file & panel log APIs ([#80](https://github.com/lt-mayonesa/hexagon/pull/80),
  [`5e4a2db`](https://github.com/lt-mayonesa/hexagon/commit/5e4a2dbb9328d43a5921a51cc3b0ed42c6abbea6))

### Refactoring

- **args**: Split args into their own modules
  ([`2eb25b6`](https://github.com/lt-mayonesa/hexagon/commit/2eb25b658626d09f038c813b66713243e5ae38f9))


## v0.57.0 (2024-03-02)

### Chores

- **tests**: Check re-prompting assigns correctly
  ([`6946c72`](https://github.com/lt-mayonesa/hexagon/commit/6946c7208adc588e3919acd9aba844087739cc5a))

### Features

- **prompt**: Allow passing callable to skip_trace
  ([`608d5dd`](https://github.com/lt-mayonesa/hexagon/commit/608d5dd99ee059bdf11528a661b501e70d186a48))


## v0.56.0 (2024-02-19)

### Chores

- **deps**: Remove unused requests lib
  ([`55f114d`](https://github.com/lt-mayonesa/hexagon/commit/55f114d28ab626ebfb1179347b9ecd4f304a5376))

### Features

- **replay**: Allow replaying last command executed
  ([#75](https://github.com/lt-mayonesa/hexagon/pull/75),
  [`7449404`](https://github.com/lt-mayonesa/hexagon/commit/7449404463ae7287989240b447eede6094ccd6ef))


## v0.55.0 (2024-02-18)

### Features

- **hexagon**: Added get-json-schema tool ([#73](https://github.com/lt-mayonesa/hexagon/pull/73),
  [`5377fbf`](https://github.com/lt-mayonesa/hexagon/commit/5377fbfaa1d4a82f16ae9d8a08cce740adb883b2))


## v0.54.0 (2024-02-18)

### Chores

- **cli**: Pipenv update command
  ([`17a0e09`](https://github.com/lt-mayonesa/hexagon/commit/17a0e0952069bfe3858b65f78f2edff20dc828fe))

- **deps**: Upgrade packages
  ([`67f5388`](https://github.com/lt-mayonesa/hexagon/commit/67f5388892674accc6cea15abec2b9f589983ad7))

- **i18n**: Check fuzzy strings
  ([`a315ffc`](https://github.com/lt-mayonesa/hexagon/commit/a315ffc1e67512f03fc77ee6162db3e34bc1b5a5))

- **i18n**: Support macos on build command
  ([`142d383`](https://github.com/lt-mayonesa/hexagon/commit/142d3835907308a847c068a1543f547e49976d7f))

### Features

- **prompt**: Allow specifying glob_extra_choices for file glop prompts
  ([#71](https://github.com/lt-mayonesa/hexagon/pull/71),
  [`d2fc570`](https://github.com/lt-mayonesa/hexagon/commit/d2fc570c5b4a4f660c0eeb40f9dc8da00eb01ad5))


## v0.53.2 (2023-11-13)

### Bug Fixes

- **i18n**: Validate existing paths
  ([`0b268e6`](https://github.com/lt-mayonesa/hexagon/commit/0b268e6a96e1886a1dd446b2f7fe483bdcc3adda))


## v0.53.1 (2023-11-12)

### Bug Fixes

- **help**: Don't print usage twice
  ([`603af0f`](https://github.com/lt-mayonesa/hexagon/commit/603af0fb1531bed4475b81c8d9175c1b53d4867e))

### Refactoring

- **help**: Hide help module function
  ([`7d11bd4`](https://github.com/lt-mayonesa/hexagon/commit/7d11bd4cec7a765ceac5cabe51cb416827feb823))


## v0.53.0 (2023-11-12)

### Features

- **args**: Allow passing boolean as key only
  ([#69](https://github.com/lt-mayonesa/hexagon/pull/69),
  [`2174082`](https://github.com/lt-mayonesa/hexagon/commit/2174082a4b2e0c5b210c6d2244d9eeea2775a31e))


## v0.52.1 (2023-11-09)

### Bug Fixes

- **prompt**: Show correct confirm dialog
  ([`c36bbb1`](https://github.com/lt-mayonesa/hexagon/commit/c36bbb12b6a76ee14abc4989ea90c18ec1857a78))

- **tracer**: Lowercase traced bool
  ([`a19f109`](https://github.com/lt-mayonesa/hexagon/commit/a19f109e359623a6f8fe94315f1584dd03a63225))


## v0.52.0 (2023-11-06)

### Chores

- **flake8**: Remove unused imports
  ([`0bee930`](https://github.com/lt-mayonesa/hexagon/commit/0bee93089fd016f49fe17a919c79c5f27c63bb97))

- **prompt**: Prompt_on_access test
  ([`46f1295`](https://github.com/lt-mayonesa/hexagon/commit/46f12955084bbdfd9ae0f9c6bc6dfdd6689f7cba))

### Features

- **prompt**: Allow defining prompt_default ([#66](https://github.com/lt-mayonesa/hexagon/pull/66),
  [`8266843`](https://github.com/lt-mayonesa/hexagon/commit/8266843ecf9766de20435c1cbcac713026113195))


## v0.51.3 (2023-11-05)

### Bug Fixes

- **i18n**: Default to EN even if nothing found
  ([`685bdef`](https://github.com/lt-mayonesa/hexagon/commit/685bdefd14b159d39f2a5106e5d26723e4e867ed))

### Chores

- **e2e**: Fix typehints for hexagonspec & better logs
  ([`5bc8309`](https://github.com/lt-mayonesa/hexagon/commit/5bc8309df5a53b0086b9b948ad452adc0b857491))

- **e2e**: Print dont wrap long lines
  ([`c68e187`](https://github.com/lt-mayonesa/hexagon/commit/c68e187b22036ea1be92d93ba64a71067a91e32c))

- **nightly**: Improve install message
  ([`35c4335`](https://github.com/lt-mayonesa/hexagon/commit/35c433528391594eaca97c6cb9982f4e95f326f7))


## v0.51.2 (2023-10-30)

### Bug Fixes

- **tracer**: Trace enum values correctly ([#63](https://github.com/lt-mayonesa/hexagon/pull/63),
  [`38475bb`](https://github.com/lt-mayonesa/hexagon/commit/38475bbb50bf252285e6c62eaab2768c15e974da))


## v0.51.1 (2023-10-29)

### Bug Fixes

- **tracer**: Execute again display enum correctly
  ([`50d575a`](https://github.com/lt-mayonesa/hexagon/commit/50d575aed1d10516fc531e0f4946ab2655086e5c))


## v0.51.0 (2023-10-29)

### Chores

- **prompt**: Pass extra model fields to validator
  ([`09d69a4`](https://github.com/lt-mayonesa/hexagon/commit/09d69a4ff7e04238fa649e0cab0e6964e6dc630b))

### Features

- **prompt**: CTRL+P create directory if not exists
  ([#61](https://github.com/lt-mayonesa/hexagon/pull/61),
  [`05002ac`](https://github.com/lt-mayonesa/hexagon/commit/05002ac13c5f492004a8edc99d4a69df965c3ab5))

### Refactoring

- **prompt**: Renames and type hints
  ([`2ef07bf`](https://github.com/lt-mayonesa/hexagon/commit/2ef07bfee431e034188f1df0fea63bcf35f1463c))


## v0.50.0 (2023-10-28)

### Chores

- **deps**: Bump urllib3 from 2.0.5 to 2.0.7 ([#58](https://github.com/lt-mayonesa/hexagon/pull/58),
  [`547da63`](https://github.com/lt-mayonesa/hexagon/commit/547da6332e6ae28d4d5a2a378bcd2af923922f96))

- **e2e**: Hexagon spec hints
  ([`8c4c53a`](https://github.com/lt-mayonesa/hexagon/commit/8c4c53aa4f015ff921adcebe02a644ba50e77c43))

### Features

- **execute**: Arg replacement
  ([`f459405`](https://github.com/lt-mayonesa/hexagon/commit/f459405d306847167b91d8f3257882d43de3a854))

### Refactoring

- Simplify decorators definition
  ([`81b8706`](https://github.com/lt-mayonesa/hexagon/commit/81b8706f92cb05074088fbe214ea9a38bd40e833))


## v0.49.2 (2023-09-27)

### Bug Fixes

- **prompt**: Handle enum default when searchable
  ([#56](https://github.com/lt-mayonesa/hexagon/pull/56),
  [`12e9987`](https://github.com/lt-mayonesa/hexagon/commit/12e9987739c74f2032d5e4251f49debf6d9cdcaf))

### Chores

- **deps**: Update python packages ([#54](https://github.com/lt-mayonesa/hexagon/pull/54),
  [`c66c876`](https://github.com/lt-mayonesa/hexagon/commit/c66c8765e3c00c17dc9a66af1eba16eed78fdd1e))


## v0.49.1 (2023-09-24)

### Bug Fixes

- **execute**: Handle script relative paths correctly
  ([`9399df5`](https://github.com/lt-mayonesa/hexagon/commit/9399df5070716d0b7642b915b82016a30c95d78a))

- **execute**: Pass first arg to script when env not present
  ([`6cbf4c0`](https://github.com/lt-mayonesa/hexagon/commit/6cbf4c09c69b4b9894dd1ccbb979c54e11b822ca))


## v0.49.0 (2023-09-20)

### Features

- **plugins**: Allow to register plugins from multiple sources
  ([#52](https://github.com/lt-mayonesa/hexagon/pull/52),
  [`2c42112`](https://github.com/lt-mayonesa/hexagon/commit/2c42112cb8df4aa9d3a7436439b6375179f5a777))


## v0.48.4 (2023-09-20)

### Bug Fixes

- **i18n**: Add messages for number & secret hints
  ([#51](https://github.com/lt-mayonesa/hexagon/pull/51),
  [`220fe6c`](https://github.com/lt-mayonesa/hexagon/commit/220fe6ce6142bb68914ea28a0edd4e704b535260))


## v0.48.3 (2023-09-18)

### Bug Fixes

- **hooks**: Terminate background hooks ([#50](https://github.com/lt-mayonesa/hexagon/pull/50),
  [`f7f762f`](https://github.com/lt-mayonesa/hexagon/commit/f7f762f4558b5633d348d2a370a8f2941e8e4dde))


## v0.48.2 (2023-09-13)

### Bug Fixes

- **tracer**: Store Enum value ([#49](https://github.com/lt-mayonesa/hexagon/pull/49),
  [`2b283d2`](https://github.com/lt-mayonesa/hexagon/commit/2b283d2838521f2bb96239f6070b73d9d063026e))


## v0.48.1 (2023-09-12)

### Bug Fixes

- **prompt**: Dont set default on inquiry type Enum
  ([`c604507`](https://github.com/lt-mayonesa/hexagon/commit/c604507fe43320430685527117fb911f51381834))


## v0.48.0 (2023-09-12)

### Features

- **prompt**: Support ints, floats, paths globs, secrets
  ([#46](https://github.com/lt-mayonesa/hexagon/pull/46),
  [`60e39fc`](https://github.com/lt-mayonesa/hexagon/commit/60e39fc200fcd197e96e44960ba7b45d448a358a))


## v0.47.1 (2023-08-07)

### Bug Fixes

- **execute**: Pass user PATH to scripts execution
  ([`6c6157c`](https://github.com/lt-mayonesa/hexagon/commit/6c6157c667563584281dbd553ed9eae8a1904add))


## v0.47.0 (2023-08-07)

### Continuous Integration

- **reports**: Set permissions for publish
  ([`a3d2d47`](https://github.com/lt-mayonesa/hexagon/commit/a3d2d470091bc4bd5488a5c3004bcc7729460b68))

### Features

- Re-organized packages ([#44](https://github.com/lt-mayonesa/hexagon/pull/44),
  [`f90bd8e`](https://github.com/lt-mayonesa/hexagon/commit/f90bd8e8e02de987ccaf6c91003c509cd89ba873))


## v0.46.2 (2023-08-06)

### Bug Fixes

- **update**: Update current git branch
  ([`7417c4d`](https://github.com/lt-mayonesa/hexagon/commit/7417c4dc50a05caaf109696363407d78746fa90f))

### Continuous Integration

- **e2e**: Retry e2e tests in case of failure
  ([`9ed2889`](https://github.com/lt-mayonesa/hexagon/commit/9ed2889da1cb04e02ec24d35934ac762f796c69e))


## v0.46.1 (2023-08-06)

### Bug Fixes

- **logger**: Check status level on status_aware
  ([`d893dcb`](https://github.com/lt-mayonesa/hexagon/commit/d893dcbc9f437efdf12ef758ae4dd84afd32071a))


## v0.46.0 (2023-08-06)

### Continuous Integration

- **nightly**: Comment PR with link to nightly release
  ([#35](https://github.com/lt-mayonesa/hexagon/pull/35),
  [`b7912de`](https://github.com/lt-mayonesa/hexagon/commit/b7912de23b5cce671cdcfec013792b66149e9b9b))

- **release**: Rollback to using personal access token
  ([`1c83083`](https://github.com/lt-mayonesa/hexagon/commit/1c8308378c26911c94b189559bb8c831449391fa))

- **release**: Use correct gh token
  ([`b0d1a35`](https://github.com/lt-mayonesa/hexagon/commit/b0d1a35edbb0adbe185dd26face3e284375970fa))

### Features

- **args**: Allow to set prompt instruction message
  ([#36](https://github.com/lt-mayonesa/hexagon/pull/36),
  [`b79ee9a`](https://github.com/lt-mayonesa/hexagon/commit/b79ee9affc456d94e3df07e01880d08f31899c5f))

- **prompt**: Show help texts for prompts
  ([`0c4ec1f`](https://github.com/lt-mayonesa/hexagon/commit/0c4ec1f96028ae45f262c6bcb3d6728149d2d387))


## v0.45.0 (2023-07-29)

### Bug Fixes

- **groups**: Display go back icon correctly
  ([`b214adc`](https://github.com/lt-mayonesa/hexagon/commit/b214adcf3d516472717b0a022ea9ca4199cda0bd))

- **update**: Show status correctly when updating
  ([`169dc99`](https://github.com/lt-mayonesa/hexagon/commit/169dc998bdf4cfdfb006e776c7f83b683bd7e858))

### Features

- **status**: Allow to nest statuses and prompt inside
  ([`d6e194e`](https://github.com/lt-mayonesa/hexagon/commit/d6e194e4c4ee9e352d9f7e484a7ce4d08dc9bcc6))


## v0.44.0 (2023-07-29)

### Bug Fixes

- **dependencies**: Show progress by individual install
  ([`c0a0f2e`](https://github.com/lt-mayonesa/hexagon/commit/c0a0f2ed15fa186a4dd05c9d196e4467497f7394))

- **dependencies**: Use faster tree search
  ([`493aa54`](https://github.com/lt-mayonesa/hexagon/commit/493aa542dfa703b08a553008eedeae2a7a616fe6))

- **install**: Use correct path for dependency install
  ([`f792d01`](https://github.com/lt-mayonesa/hexagon/commit/f792d0121f1cc20f0e95eafe013bfedc325ce58f))

### Documentation

- Rollback changelog
  ([`eee2034`](https://github.com/lt-mayonesa/hexagon/commit/eee2034442be6b9410a2866a58b3f0b1d9261e88))

- **setup**: Update local setup instractions
  ([`12a7da7`](https://github.com/lt-mayonesa/hexagon/commit/12a7da732aabb517e1be83487b5e624fa656dfc8))

### Features

- **args**: Allow to specify default in prompt
  ([`69303d3`](https://github.com/lt-mayonesa/hexagon/commit/69303d3ad38c110a0ff75807dcf580ef2af10fea))


## v0.43.2 (2023-07-24)

### Bug Fixes

- **dependencies**: Handle case when no custom dir present
  ([`ff7a5e8`](https://github.com/lt-mayonesa/hexagon/commit/ff7a5e8292a1120ec4b053ba516ed752e84cba70))

- **errors**: Handle case when no custom dir present
  ([`61362ba`](https://github.com/lt-mayonesa/hexagon/commit/61362ba4f251763bca573f7936c75655a6fa50f4))

- **release**: Empty change to trigger new release
  ([`f4d7492`](https://github.com/lt-mayonesa/hexagon/commit/f4d7492263672d3816f2f9e5fae9ae85cf7c2669))

- **release**: Rollback to v7.34.6
  ([`372fa02`](https://github.com/lt-mayonesa/hexagon/commit/372fa0256fde3e6c1d6ae15ec4a69a1e84aa6e71))

- **update**: Ignore versions entries with chore types
  ([`5e063c4`](https://github.com/lt-mayonesa/hexagon/commit/5e063c4d431f7fdde91c6242bccd1c500cb44dbe))

### Chores

- **e2e**: 3.7 failing test
  ([`cb360b0`](https://github.com/lt-mayonesa/hexagon/commit/cb360b0baacd899e527326a0fae75c880640e769))

- **e2e**: Allow to specify multiple yaml
  ([`5da4d92`](https://github.com/lt-mayonesa/hexagon/commit/5da4d9272cfda5440ea6a55033ddb4dcf6383cc0))

### Continuous Integration

- **release**: Migrate to v8 of semantic release
  ([`ec9a531`](https://github.com/lt-mayonesa/hexagon/commit/ec9a5315abfa8a6f07982d2a6edba87064bf75ee))

### Refactoring

- **dependencies**: Dry up code
  ([`b8a843e`](https://github.com/lt-mayonesa/hexagon/commit/b8a843e46fab26953f6949697fa5d772dc2bb229))


## v0.43.1 (2023-07-09)

### Bug Fixes

- **install**: Use string instead of posixpath
  ([`f645906`](https://github.com/lt-mayonesa/hexagon/commit/f64590691f3e7c7d5c1e7bfa073b01c9806c1821))

- **update**: Ignore errors when updating
  ([`2a40c98`](https://github.com/lt-mayonesa/hexagon/commit/2a40c98cb2154123ba4e2d7428b733afdaae8993))

### Chores

- Removed unused pipenv-setup ([#24](https://github.com/lt-mayonesa/hexagon/pull/24),
  [`ba91768`](https://github.com/lt-mayonesa/hexagon/commit/ba917681fb7a4decd9b0f50166a1abd7a1f7ce37))

- **e2e**: Fix flaky test
  ([`5a946f7`](https://github.com/lt-mayonesa/hexagon/commit/5a946f7f582d99de73d9be29629f572827f8f32e))

- **flake8**: Remove unused variable
  ([`09165d1`](https://github.com/lt-mayonesa/hexagon/commit/09165d180b5e6d0a8aea3ee8492f9aaf8e10debf))

- **update**: Don't use local imports
  ([`0f5e2a6`](https://github.com/lt-mayonesa/hexagon/commit/0f5e2a6189c87a399b1fe15caaf7d8b59567b090))

- **update**: Handle deprecated package pkg_resources
  ([`cc63668`](https://github.com/lt-mayonesa/hexagon/commit/cc636681d185878edcf99deb0cecda1c6c09f882))

- **update**: Parse test version correctly
  ([`20f3517`](https://github.com/lt-mayonesa/hexagon/commit/20f35171d3566e5fdbb923492f63fdd24779662f))

- **update**: Revert local imports usage
  ([`ff32c5b`](https://github.com/lt-mayonesa/hexagon/commit/ff32c5b26f58f3d1ea0e9ff67eeb3ab73f447d45))

### Testing

- **e2e**: Add bigger timeout
  ([`0b148e9`](https://github.com/lt-mayonesa/hexagon/commit/0b148e963524f73c853bd255a15266d91646de4d))

- **e2e**: Extra ouput validation
  ([`c71db14`](https://github.com/lt-mayonesa/hexagon/commit/c71db14bb5444c43c5e60a05fd7c53770c5d63e2))

- **e2e**: Match output
  ([`1dcfecc`](https://github.com/lt-mayonesa/hexagon/commit/1dcfeccc31494bed18f162ace8bc72834fc66d4a))

- **e2e**: Output complete log even on errors
  ([`807d19a`](https://github.com/lt-mayonesa/hexagon/commit/807d19aadc73303c2d5a5af0cd56245dc05ed7ec))

- **e2e**: Use no_border theme instead of default
  ([`b03162b`](https://github.com/lt-mayonesa/hexagon/commit/b03162b7215710d9af46c837d5b79c3a9e764fc7))

- **e2e**: Validate more outputs
  ([`787f329`](https://github.com/lt-mayonesa/hexagon/commit/787f329199d385472a733c028bbdd57dea8bd317))


## v0.43.0 (2023-05-06)

### Features

- **args**: Prompt same arg multiple times and trace
  ([`7a96e23`](https://github.com/lt-mayonesa/hexagon/commit/7a96e23cc8e2c69b6f2e07558bd37041af927830))


## v0.42.1 (2023-05-06)

### Bug Fixes

- **args**: Use correct value when tracing
  ([`f00dac8`](https://github.com/lt-mayonesa/hexagon/commit/f00dac85f2e10621826a9312f5d2eab02271606a))


## v0.42.0 (2023-05-02)

### Features

- **args**: Add prompt API to hexagon args
  ([`6cfb88f`](https://github.com/lt-mayonesa/hexagon/commit/6cfb88fc309a303ee234821754b061ae4606404f))


## v0.41.1 (2023-04-13)

### Bug Fixes

- **args**: Apply default type validation when prompting
  ([`f97911f`](https://github.com/lt-mayonesa/hexagon/commit/f97911faee9d4437d2f92344276a8c69af346270))

### Chores

- **test**: Ignore blank lines when matching outout
  ([`9607636`](https://github.com/lt-mayonesa/hexagon/commit/96076362b10dbc2f3d9f02440346b460b2ef37f9))


## v0.41.0 (2023-04-13)

### Chores

- **dependencies**: Update to newest versions
  ([`c1bc52d`](https://github.com/lt-mayonesa/hexagon/commit/c1bc52daae64de2e51da04e60ad15819c3ca366d))

- **test**: Log hexagon spec steps
  ([`f1a3e00`](https://github.com/lt-mayonesa/hexagon/commit/f1a3e00cd8e8b064a65141d3eee7ca7107fd4a5b))

### Features

- **theme**: Add no_border prompt theme
  ([`bb39265`](https://github.com/lt-mayonesa/hexagon/commit/bb39265274507eeac3c47605d41bc0b21d317de1))


## v0.40.0 (2023-04-12)

### Features

- **args**: Do not validate special characters on args
  ([`e793175`](https://github.com/lt-mayonesa/hexagon/commit/e79317551d686021d50915c61e25de69d80bf29e))

- **args**: Wrap default value in HexagonArg
  ([`7d5eae4`](https://github.com/lt-mayonesa/hexagon/commit/7d5eae4da5d56768664968dacab08a5ce64b706a))

### Refactoring

- **args**: Rename Field to Arg
  ([`b742568`](https://github.com/lt-mayonesa/hexagon/commit/b742568336920d82b7a7b6e319d62e0e1f31951a))

- **args**: Use positional and optional instances
  ([`b1f9e61`](https://github.com/lt-mayonesa/hexagon/commit/b1f9e613200fe40b48365984a272046c3f34a0cb))


## v0.39.0 (2023-04-10)

### Features

- **args**: Apply model validations when prompting
  ([`86bf096`](https://github.com/lt-mayonesa/hexagon/commit/86bf096817194810d0143bc98bfafad575435115))

- **args**: Prompt for tool arguments from cli_args object
  ([`67d65ab`](https://github.com/lt-mayonesa/hexagon/commit/67d65ab9a4a20cc9b6d7438854cc480decdbbb07))

### Refactoring

- **inquirer**: Hide usage behind prompt
  ([`d68d01c`](https://github.com/lt-mayonesa/hexagon/commit/d68d01c9da08343acba94ca81d170bdb3b2ba938))

- **tracer**: Store trace object instead of string
  ([`4c79362`](https://github.com/lt-mayonesa/hexagon/commit/4c793622ceea67fb6373089b536de6859daa5e9f))


## v0.38.1 (2023-04-06)

### Bug Fixes

- **args**: Trace all input args and one time only
  ([`8b69454`](https://github.com/lt-mayonesa/hexagon/commit/8b6945487dddf9d4bb31a916743689e1831ee13b))


## v0.38.0 (2023-04-05)

### Continuous Integration

- Adjust workflow naming
  ([`91e94c3`](https://github.com/lt-mayonesa/hexagon/commit/91e94c3034b5f97b6c17cfeb30469deef28a5785))

- Use github environment files
  ([`fbffcc3`](https://github.com/lt-mayonesa/hexagon/commit/fbffcc3b0583aad35dc18a7f7515f4446063b6ee))

### Features

- **execute**: When executing script pass tool & env as envvars
  ([`2c17a33`](https://github.com/lt-mayonesa/hexagon/commit/2c17a332215f1936de97549a450f36aac64cc86a))

### Refactoring

- Centralize error handling in main catch
  ([`dd648bc`](https://github.com/lt-mayonesa/hexagon/commit/dd648bc2986a838cf989c1442a3df19a7147d6bd))

- Reducing main complexity
  ([`40969b6`](https://github.com/lt-mayonesa/hexagon/commit/40969b681f1d06780ff24c23ad1581f6a93c01a2))

- Remove dependency from plugins
  ([`90ab695`](https://github.com/lt-mayonesa/hexagon/commit/90ab69533dd2052fbb4346ca0513a9bf54603dd4))

- Remove logic from hexagon.domain.__init__
  ([`e283f88`](https://github.com/lt-mayonesa/hexagon/commit/e283f88db627039705e55b9184c2052210ab0ced))

- **tracer**: Handle execute again in tracer
  ([`a8b11da`](https://github.com/lt-mayonesa/hexagon/commit/a8b11dabd276648bca88d97322e771c6a78067f0))


## v0.37.0 (2023-04-03)

### Chores

- **i18n**: Fix message id
  ([`b66d48d`](https://github.com/lt-mayonesa/hexagon/commit/b66d48d47589246df7ae4ea1fdf522df9735c4d7))

### Continuous Integration

- **report**: Add comment to PR with tests results
  ([`865b3cc`](https://github.com/lt-mayonesa/hexagon/commit/865b3cc26bab86396fde855ee15a814c1351a972))

### Features

- **args**: Show validation error matching hexagon format
  ([`6027468`](https://github.com/lt-mayonesa/hexagon/commit/6027468e00b645c64b29f08f1313754033971774))


## v0.36.0 (2023-04-02)

### Features

- **args**: Show help text for tools
  ([`9e387a7`](https://github.com/lt-mayonesa/hexagon/commit/9e387a7f0872029fd703c0bb87fba35ac6b7aa71))


## v0.35.1 (2023-04-01)

### Bug Fixes

- **args**: Handle case when last optional arg has missing value
  ([`e05004b`](https://github.com/lt-mayonesa/hexagon/commit/e05004bf393ed79bf3a7283fe4d8938aa3a5d236))


## v0.35.0 (2023-04-01)

### Bug Fixes

- **args**: Support extend on python 3.7
  ([`e4c0581`](https://github.com/lt-mayonesa/hexagon/commit/e4c0581a75a635dfb43f1a7166e1f0fd023b7a6d))

### Chores

- **e2e**: Always print command output
  ([`d9a88a6`](https://github.com/lt-mayonesa/hexagon/commit/d9a88a683ef22725189dff7ae2717aa0a6a43e4d))

### Continuous Integration

- **report**: Use wildcard for reports
  ([`ceb4dcd`](https://github.com/lt-mayonesa/hexagon/commit/ceb4dcd9765e24399c6b8083961aea7e4f8f003a))

### Features

- **args**: Added support for tool args
  ([`ebd5443`](https://github.com/lt-mayonesa/hexagon/commit/ebd5443d2d732099765cd7fb869e8cc70818b85e))

### Refactoring

- **args**: Rename support module
  ([`26c3cd5`](https://github.com/lt-mayonesa/hexagon/commit/26c3cd56675484efae39b755f4a7eb52ad09a945))


## v0.34.0 (2023-03-27)

### Chores

- Updating directories structure
  ([`7174bb2`](https://github.com/lt-mayonesa/hexagon/commit/7174bb24221843ed4946bd8f32cb3d663f2eff28))

- **e2e**: Set terminal COLUMNS size to 200
  ([`99b431e`](https://github.com/lt-mayonesa/hexagon/commit/99b431e8408a63cd5ccbb9f2c78a65f50ae96c9f))

### Continuous Integration

- **report**: Added unit tests junit report
  ([`6cc05e9`](https://github.com/lt-mayonesa/hexagon/commit/6cc05e9f7b790146f6c674beaea67deb1e946b60))

### Features

- **tracer**: Add support for optional cli_args
  ([`a7b5a9d`](https://github.com/lt-mayonesa/hexagon/commit/a7b5a9d9779c3990687db31c83f20393dd552bec))


## v0.33.0 (2023-03-26)

### Chores

- Fix flake8 reports
  ([`29167b5`](https://github.com/lt-mayonesa/hexagon/commit/29167b55c409d5dfc57f0f0c31375ac88755b5f5))

- **i18n**: Update po line references
  ([`8b35967`](https://github.com/lt-mayonesa/hexagon/commit/8b359677218c25dda69d82a7fe79057a8d42604e))

- **test**: Stub i18n for unit tests
  ([`5e60597`](https://github.com/lt-mayonesa/hexagon/commit/5e60597a18b1730c5149f760539a2b0685a3be80))

### Features

- **cli-args**: Pass extra cli args to execution of actions
  ([`528827a`](https://github.com/lt-mayonesa/hexagon/commit/528827a3130abbbd4318846036130f9370ff55f0))

### Refactoring

- Use decorator for execute hook
  ([`ce5d8dc`](https://github.com/lt-mayonesa/hexagon/commit/ce5d8dc5c72f0f6a1b9f229ea02c305902514223))

- **cli-args**: Use argparse for better support
  ([`d26d33f`](https://github.com/lt-mayonesa/hexagon/commit/d26d33f4335c8be4507d8adede345ec46b4e16d7))


## v0.32.0 (2023-03-16)

### Chores

- **e2e**: Skip timeout when debugging
  ([`c5523a9`](https://github.com/lt-mayonesa/hexagon/commit/c5523a9cda1e94b8a4455bae0f3a02afab20eae6))

### Continuous Integration

- **report**: Use github token
  ([`6e78d9c`](https://github.com/lt-mayonesa/hexagon/commit/6e78d9cc107b93f05b05621bb6d81f70421441b1))

### Features

- **options**: Allow override options at yaml level
  ([`08f4258`](https://github.com/lt-mayonesa/hexagon/commit/08f425800f4b719cceb3391e59a1965c7f57c856))


## v0.31.0 (2023-03-13)

### Continuous Integration

- **test**: Upload test report to github
  ([`4a76871`](https://github.com/lt-mayonesa/hexagon/commit/4a76871b4b052aae4a28d42b7a9c5415dc9b7c36))

- **test**: Use java-junit reporter
  ([`057d1b3`](https://github.com/lt-mayonesa/hexagon/commit/057d1b37c182eb925e9dfcba089c03a321204441))

### Features

- **analytics**: Remove support for tracking
  ([`e8adefe`](https://github.com/lt-mayonesa/hexagon/commit/e8adefe440294988742d93d7bcd13454b2e03696))


## v0.30.0 (2023-03-12)

### Continuous Integration

- Update project metadata
  ([`a7c311d`](https://github.com/lt-mayonesa/hexagon/commit/a7c311dc8e5968102841961d7fa352a4bd263ac6))

- **devex**: Use personal access token
  ([`4996bc3`](https://github.com/lt-mayonesa/hexagon/commit/4996bc3d902efd1bd64d849f471487fba3f990a6))

### Features

- **messages**: Show path when installing dependencies
  ([`b060dcc`](https://github.com/lt-mayonesa/hexagon/commit/b060dcc8b4311dbf03713b0ef76a0056b222cf96))


## v0.29.0 (2023-03-12)

- Initial Release
